@@ -58,7 +58,8 @@ def play_calc_score_set(played_cards, players):
             go_played_by = last_player(cards, players)
             players_in_play.remove(go_played_by)
 
-        cards = remove_goes(cards)
+        # Remove GOs
+        cards = [card for card in cards if card != (0, "GO")]
 
         count, score, msg = play_score_ongoing(cards, index == len(played_cards))
 
@@ -70,15 +71,9 @@ def play_calc_score_set(played_cards, players):
         else:
             play_log.append(f"Count: {count}, No Points scored, {go_played_by} said Go. ")
 
-    return dict(scores), count, play_log
+    return scores, count, play_log
 
 
-def remove_goes(played_cards):
-    cards = played_cards.copy()
-    while (0, "GO") in cards:
-        cards.remove((0, "GO"))
-    return cards
-
 
 def play_score_ongoing(played_cards, last_card=False):
     
@@ -309,10 +304,13 @@ def score_runs(card_nums):
         group_list = list(group)
         group_length = len(group_list)
         if group_length >= 3:
-            multiples_length = len(count_multiples(card_nums))
-            if multiples_length > 0:
-                running_msg.append(f"Multi-run: {card_nameify(card_nums)} ({group_length * multiples_length}pts)")
-                running_score.append((group_length * multiples_length))
+            the_multiples = count_multiples(card_nums)
+
+            multiples_in_run = sum([1 for card_num in the_multiples if card_num in group_list])
+
+            if multiples_in_run > 0:
+                running_msg.append(f"Multi-run: {card_nameify(card_nums)} ({group_length * multiples_in_run}pts)")
+                running_score.append((group_length * multiples_in_run))
             else:
                 running_score.append(group_length)
                 running_msg.append(f"Run of {group_length} cards ({group_length}pts)")
